summaryrefslogtreecommitdiffstats
path: root/tools/src/h5jam/h5jam.c
diff options
context:
space:
mode:
Diffstat (limited to 'tools/src/h5jam/h5jam.c')
-rw-r--r--tools/src/h5jam/h5jam.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/tools/src/h5jam/h5jam.c b/tools/src/h5jam/h5jam.c
index 7f3385c..07140b5 100644
--- a/tools/src/h5jam/h5jam.c
+++ b/tools/src/h5jam/h5jam.c
@@ -358,7 +358,7 @@ done:
* Purpose: Copy part of the input file to output.
* infid: fd of file to read
* outfid: fd of file to write
* startin: offset of where to read from infid
* startout: offset of where to write to outfid
* limit: bytes to read/write
*
@@ -373,7 +373,7 @@ done:
*-------------------------------------------------------------------------
*/
hsize_t
-copy_some_to_file(int infid, int outfid, hsize_t startin, hsize_t startout, ssize_t limit)
+copy_some_to_file(int infid, int outfid, hsize_t starting, hsize_t startout, ssize_t limit)
{
char buf[1024];
h5_stat_t sbuf;
@@ -386,9 +386,9 @@ copy_some_to_file(int infid, int outfid, hsize_t startin, hsize_t startout, ssiz
ssize_t toend;
ssize_t fromend;
- if (startin > startout) {
+ if (starting > startout) {
/* this case is prohibited */
- error_msg("copy_some_to_file: panic: startin > startout?\n");
+ error_msg("copy_some_to_file: panic: starting > startout?\n");
exit(EXIT_FAILURE);
} /* end if */
@@ -409,7 +409,7 @@ copy_some_to_file(int infid, int outfid, hsize_t startin, hsize_t startout, ssiz
return 0;
toend = (ssize_t)startout + howmuch;
- fromend = (ssize_t)startin + howmuch;
+ fromend = (ssize_t)starting + howmuch;
if (howmuch > 512) {
to = toend - 512;
@@ -358,7 +358,7 @@ done:
* infid: fd of file to read
* outfid: fd of file to write
- * startin: offset of where to read from infid
+ * starting: offset of where to read from infid
* startout: offset of where to write to outfid
* limit: bytes to read/write